/* Symbol rediretion for loader/static initialization code.
   Copyright (C) 2022-2025 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   <https://www.gnu.org/licenses/>.  */

#ifndef _DL_IFUNC_GENERIC_H
#define _DL_IFUNC_GENERIC_H

#include <ifunc-memset.h>
#include <ifunc-memcmp.h>

#define IFUNC_SYMBOL_STR1(s)	#s
#define IFUNC_SYMBOL_STR(s)	IFUNC_SYMBOL_STR1(s)

asm ("memset = " IFUNC_SYMBOL_STR(MEMSET_DEFAULT));
asm ("memcmp = " IFUNC_SYMBOL_STR(MEMCMP_DEFAULT));

#endif
